package de.intevation.flys.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.GeneratedValue;
import javax.persistence.Column;
import javax.persistence.SequenceGenerator;
import javax.persistence.GenerationType;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;
import javax.persistence.OneToMany;

import org.apache.log4j.Logger;


@Entity
@Table(name = "waterlevel_difference")
public class WaterlevelDifference
implements   Serializable
{
    private static Logger logger = Logger.getLogger(WaterlevelDifference.class);

    private Integer id;

    private River river;

    private Unit unit;

    private List<WaterlevelDifferenceColumn> columns;

    private String description;


    public WaterlevelDifference() {
        columns = new ArrayList<WaterlevelDifferenceColumn>();
    }


    public WaterlevelDifference(River river, Unit unit) {
        this();

        this.river = river;
        this.unit  = unit;
    }


    public WaterlevelDifference(River river, Unit unit, String description) {
        this(river, unit);

        this.description = description;
    }


    @Id
    @SequenceGenerator(
        name           = "SEQUENCE_WATERLEVEL_DIFFERENCE_ID_SEQ",
        sequenceName   = "WATERLEVEL_DIFFERENCE_ID_SEQ",
        allocationSize = 1)
    @GeneratedValue(
        strategy  = GenerationType.SEQUENCE,
        generator = "SEQUENCE_WATERLEVEL_DIFFERENCE_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "river_id" )
    public River getRiver() {
        return river;
    }

    public void setRiver(River river) {
        this.river = river;
    }

    @OneToOne
    @JoinColumn(name = "unit_id")
    public Unit getUnit() {
        return unit;
    }

    public void setUnit(Unit unit) {
        this.unit = unit;
    }

    @Column(name = "description")
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    @OneToMany
    @JoinColumn(name = "difference_id")
    public List<WaterlevelDifferenceColumn> getColumns() {
        return columns;
    }

    public void setColumns(List<WaterlevelDifferenceColumn> columns) {
        this.columns = columns;
    }

    public void addColumn(WaterlevelDifferenceColumn column) {
        this.columns.add(column);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
